MFBuilding class

Draws a Building on the Map

Annotations

Constructors

MFBuilding({required MFBuildingId buildingId, bool consumeTapEvents = false, String name = '', MFLatLng position = const MFLatLng(0, 0), List<MFLatLng> coordinates = const <MFLatLng>[], String modelUrl = '', String textureUrl = '', double height = 1, double scale = 1, double bearing = 0, double elevation = 0, bool selected = false, bool visible = true, VoidCallback? onTap})
Creates an immutable representation of a MFPOI to draw on Map4dMap.
const

Properties

bearing → double
final
buildingId → MFBuildingId
Uniquely identifies a MFBuilding.
final
consumeTapEvents → bool
True if the MFBuilding consumes tap events.
final
coordinates → List<MFLatLng>
final
elevation → double
final
hashCode → int
The hash code for this object.
no setteroverride
height → double
final
mapsId → MFBuildingId
A identifier for this object.
no setter
modelUrl → String
final
name → String
Name of the building.
final
onTap → VoidCallback?
Callbacks to receive tap events for building placed on this map.
final
position → MFLatLng
Geographical location of the POI.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
selected → bool
final
textureUrl → String
final
visible → bool
True if the building is visible.
final

Methods

clone() → MFBuilding
Creates a new MFBuilding object whose values are the same as this instance.
copyWith({bool? consumeTapEventsParam, String? nameParam, MFLatLng? positionParam, List<MFLatLng>? coordinatesParam, String? modelUrlParam, String? textureUrlParam, double? heightParam, double? scaleParam, double? bearingParam, double? elevationParam, bool? selectedParam, bool? visibleParam, VoidCallback? onTapParam}) → MFBuilding
Creates a new MFBuilding object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override