MFCameraPosition class

Constructors

MFCameraPosition({double bearing = 0.0, required MFLatLng target, double tilt = 0.0, double zoom = 0.0})
Creates a immutable representation of the Map4dMap camera.
const

Properties

bearing → double
The camera's bearing in degrees, measured clockwise from north.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → MFLatLng
The geographical location that the camera is pointing at.
final
tilt → double
The angle, in degrees, of the camera angle from the nadir.
final
zoom → double
The zoom level of the camera.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Object
Serializes MFCameraPosition.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromMap(Object? json) → MFCameraPosition?
Deserializes MFCameraPosition from a map.