MFCircle class

Draws a circle on the map.

Annotations

Constructors

MFCircle({required MFCircleId circleId, bool consumeTapEvents = false, Color fillColor = Colors.transparent, MFLatLng center = const MFLatLng(0.0, 0.0), double radius = 0, Color strokeColor = Colors.black, int strokeWidth = 10, bool visible = true, int zIndex = 0, VoidCallback? onTap})
Creates an immutable representation of a MFCircle to draw on Map4dMap.
const

Properties

center → MFLatLng
Geographical location of the circle center.
final
circleId → MFCircleId
Uniquely identifies a MFCircle.
final
consumeTapEvents → bool
True if the MFCircle consumes tap events.
final
fillColor → Color
Fill color in ARGB format, the same format used by Color. The default value is transparent (0x00000000).
final
hashCode → int
The hash code for this object.
no setteroverride
mapsId → MFCircleId
A identifier for this object.
no setter
onTap → VoidCallback?
Callbacks to receive tap events for circle placed on this map.
final
radius → double
Radius of the circle in meters; must be positive. The default value is 0.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor → Color
Fill color in ARGB format, the same format used by Color. The default value is black (0xff000000).
final
strokeWidth → int
The width of the circle's outline in screen points.
final
visible → bool
True if the circle is visible.
final
zIndex → int
The z-index of the circle, used to determine relative drawing order of map overlays.
final

Methods

clone() → MFCircle
Creates a new MFCircle object whose values are the same as this instance.
copyWith({bool? consumeTapEventsParam, Color? fillColorParam, MFLatLng? centerParam, double? radiusParam, Color? strokeColorParam, int? strokeWidthParam, bool? visibleParam, int? zIndexParam, VoidCallback? onTapParam}) → MFCircle
Creates a new MFCircle object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override