MFDataSourceFeature class

Constructors

MFDataSourceFeature(String source, String sourceLayer, String layerType, Map<String, dynamic> properties)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
layerType → String
final
properties → Map<String, dynamic>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String
final
sourceLayer → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Object? json) → MFDataSourceFeature?