MFDirectionsPOIOptions class

Constructors

MFDirectionsPOIOptions({MFLatLng? position, MFBitmap? icon, String? title, Color? titleColor, bool visible = true})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → MFBitmap?
A description of the bitmap used to draw the directions icon.
final
position → MFLatLng?
Geographical location of the directions poi.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Title of the directions poi.
final
titleColor → Color?
Title color in ARGB format, the same format used by Color. The default value is black (0xff000000).
final
visible → bool
True if the directions poi is visible. The default is true.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited