MFDirectionsRenderer class

Draws a gon through geographical locations on the map.

Annotations

Constructors

MFDirectionsRenderer({required MFDirectionsRendererId rendererId, List<List<MFLatLng>> routes = const <List<MFLatLng>>[], String directions = "", int activedIndex = 0, int activeStrokeWidth = 8, Color activeStrokeColor = Colors.blue, int activeOutlineWidth = 2, Color activeOutlineColor = const Color(0xFF0D47A1), int inactiveStrokeWidth = 8, Color inactiveStrokeColor = Colors.blueGrey, int inactiveOutlineWidth = 1, Color inactiveOutlineColor = const Color(0xFF263238), MFDirectionsPOIOptions originPOIOptions = const MFDirectionsPOIOptions(), MFDirectionsPOIOptions destinationPOIOptions = const MFDirectionsPOIOptions(), MFDirectionsCallback? onRouteTap})
Creates an immutable object representing a gon drawn through geographical locations on the map.
const

Properties

activedIndex → int
The index of the main route, default value is 0.
final
activeOutlineColor → Color
The active route outline color.
final
activeOutlineWidth → int
The active route outline stroke width.
final
activeStrokeColor → Color
The active route color.
final
activeStrokeWidth → int
The active route stroke width.
final
destinationPOIOptions → MFDirectionsPOIOptions
The options for destination poi placed on the map.
final
directions → String
The directions to display on the map, retrieved as a json string from Get route Map4D API (/sdk/route).
final
hashCode → int
The hash code for this object.
no setteroverride
inactiveOutlineColor → Color
The inactive route outline color.
final
inactiveOutlineWidth → int
The inactive route outline stroke width.
final
inactiveStrokeColor → Color
The inactive route color.
final
inactiveStrokeWidth → int
The inactive route stroke width.
final
mapsId → MFDirectionsRendererId
A identifier for this object.
no setter
onRouteTap → MFDirectionsCallback?
Callbacks to receive tap events for direction route placed on this map.
final
originPOIOptions → MFDirectionsPOIOptions
The options for origin poi placed on the map.
final
rendererId → MFDirectionsRendererId
Uniquely identifies a MFDirectionsRenderer.
final
routes → List<List<MFLatLng>>
The directions to display on the map.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → MFDirectionsRenderer
Creates a new MFDirectionsRenderer object whose values are the same as this instance.
copyWith({List<List<MFLatLng>>? routesParam, String? directionsParam, int? activedIndexParam, int? activeStrokeWidthParam, Color? activeStrokeColorParam, int? activeOutlineWidthParam, Color? activeOutlineColorParam, int? inactiveStrokeWidthParam, Color? inactiveStrokeColorParam, int? inactiveOutlineWidthParam, Color? inactiveOutlineColorParam, MFDirectionsPOIOptions? originPOIOptionsParam, MFDirectionsPOIOptions? destinationPOIOptionsParam, MFDirectionsCallback? onRouteTapParam}) → MFDirectionsRenderer
Creates a new MFDirectionsRenderer object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override