activeStrokeWidth property
The active route stroke width.
The width is constant and independent of the camera's zoom level. The default value is 8.
Implementation
final int activeStrokeWidth;
The active route stroke width.
The width is constant and independent of the camera's zoom level. The default value is 8.
final int activeStrokeWidth;