MFInfoWindow class

Text labels for a Marker info window.

Constructors

MFInfoWindow({String? title, String? snippet, Offset anchor = const Offset(0.5, 0.0), VoidCallback? onTap})
Creates an immutable representation of a label on for Marker.
const

Properties

anchor → Offset
final
hashCode → int
The hash code for this object.
no setteroverride
onTap → VoidCallback?
onTap callback for this MFInfoWindow.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet → String?
final
title → String?
final

Methods

copyWith({String? titleParam, String? snippetParam, Offset? anchorParam, VoidCallback? onTapParam}) → MFInfoWindow
Creates a new MFInfoWindow object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

noText → const MFInfoWindow
Text labels specifying that no text is to be displayed.