noText constant
MFInfoWindow
const noText
Text labels specifying that no text is to be displayed.
Implementation
static const MFInfoWindow noText = MFInfoWindow();
Text labels specifying that no text is to be displayed.
static const MFInfoWindow noText = MFInfoWindow();