MFLatLngBounds class

Constructors

MFLatLngBounds({required MFLatLng southwest, required MFLatLng northeast})
Creates geographical bounding box with the specified corners.

Properties

hashCode → int
The hash code for this object.
no setteroverride
northeast → MFLatLng
The northeast corner of the rectangle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
southwest → MFLatLng
The southwest corner of the rectangle.
final

Methods

contains(MFLatLng point) → bool
Returns whether this rectangle contains the given MFLatLng.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object o) → bool
The equality operator.
override

Static Methods

fromList(Object? json) → MFLatLngBounds?
Converts a list to MFLatLngBounds.