MFMapType enum

Type of map tiles to display

Inheritance
Available extensions

Values

roadmap → const MFMapType

Roadmap maps, default

raster → const MFMapType

Raster maps

satellite → const MFMapType

Satellite maps

map3D → const MFMapType

3D maps

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MFMapType>
A constant List of the values in this enum, in order of their declaration.