MFMarker class

Annotations

Constructors

MFMarker({required MFMarkerId markerId, bool consumeTapEvents = false, MFLatLng position = const MFLatLng(0.0, 0.0), double elevation = 0.0, double rotation = 0.0, Offset anchor = const Offset(0.5, 0.5), bool draggable = false, bool visible = true, double zIndex = 0.0, MFBitmap icon = MFBitmap.defaultIcon, MFInfoWindow infoWindow = MFInfoWindow.noText, VoidCallback? onTap, ValueChanged<MFLatLng>? onDragEnd})
const

Properties

anchor → Offset
final
consumeTapEvents → bool
True if the MFMarker consumes tap events.
final
draggable → bool
final
elevation → double
final
hashCode → int
The hash code for this object.
no setteroverride
icon → MFBitmap
A description of the bitmap used to draw the marker icon.
final
infoWindow → MFInfoWindow
The window is displayed when the marker is tapped.
final
mapsId → MFMarkerId
A identifier for this object.
no setter
markerId → MFMarkerId
final
onDragEnd → ValueChanged<MFLatLng>?
Signature reporting the new MFLatLng at the end of a drag event.
final
onTap → VoidCallback?
Callbacks to receive tap events for marker placed on this map.
final
position → MFLatLng
final
rotation → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visible → bool
final
zIndex → double
final

Methods

clone() → MFMarker
Returns a duplicate of this object.
copyWith({bool? consumeTapEventsParam, MFLatLng? positionParam, Offset? anchorParam, double? elevationParam, double? rotationParam, bool? draggableParam, bool? visibleParam, double? zIndexParam, MFBitmap? iconParam, MFInfoWindow? infoWindowParam, VoidCallback? onTapParam, ValueChanged<MFLatLng>? onDragEndParam}) → MFMarker
Creates a new MFMarker object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override