MFPolyline class

Draws a line through geographical locations on the map.

Annotations

Constructors

MFPolyline({required MFPolylineId polylineId, bool consumeTapEvents = false, Color color = Colors.black, MFPolylineStyle style = MFPolylineStyle.solid, List<MFLatLng> points = const <MFLatLng>[], bool visible = true, int width = 10, int zIndex = 0, VoidCallback? onTap})
Creates an immutable object representing a line drawn through geographical locations on the map.
const

Properties

color → Color
Line segment color in ARGB format, the same format used by Color. The default value is black (0xff000000).
final
consumeTapEvents → bool
True if the MFPolyline consumes tap events.
final
hashCode → int
The hash code for this object.
no setteroverride
mapsId → MFPolylineId
A identifier for this object.
no setter
onTap → VoidCallback?
Callbacks to receive tap events for polyline placed on this map.
final
points → List<MFLatLng>
The vertices of the polyline to be drawn.
final
polylineId → MFPolylineId
Uniquely identifies a MFPolyline.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → MFPolylineStyle
Style of Polyline: solid or dooted.
final
visible → bool
True if the marker is visible.
final
width → int
Width of the polyline, used to define the width of the line segment to be drawn.
final
zIndex → int
The z-index of the polyline, used to determine relative drawing order of map overlays.
final

Methods

clone() → MFPolyline
Creates a new MFPolyline object whose values are the same as this instance.
copyWith({Color? colorParam, bool? consumeTapEventsParam, MFPolylineStyle? styleParam, List<MFLatLng>? pointsParam, bool? visibleParam, int? widthParam, int? zIndexParam, VoidCallback? onTapParam}) → MFPolyline
Creates a new MFPolyline object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to something serializable in JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override