MFTileOverlay class

A set of images which are displayed on top of the base map tiles.

Properties

hashCode → int
The hash code for this object.
no setteroverride
mapsId → MFTileOverlayId
A identifier for this object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileOverlayId → MFTileOverlayId
Uniquely identifies a MFTileOverlay.
final
transparency → double
The transparency of the tile overlay. The default transparency is 0 (opaque).
final
urlPattern → String
final
visible → bool
The visibility for the tile overlay. The default visibility is true.
final
zIndex → int
The tile overlay's zIndex, i.e., the order in which it will be drawn where overlays with larger values are drawn above those with lower values
final

Methods

clone() → MFTileOverlay
Returns a duplicate of this object.
copyWith({double? transparencyParam, int? zIndexParam, bool? visibleParam}) → MFTileOverlay
Creates a new MFTileOverlay object whose values are the same as this instance, unless overwritten by the specified parameters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
Converts this object to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

newWithUrlPattern(MFTileOverlayId tileOverlayId, String urlPattern, {double transparency = 0.0, int zIndex = 0, bool visible = true}) → MFTileOverlay