MFMapView class

Inheritance

Constructors

MFMapView({Key? key, MFCameraPosition? initialCameraPosition, MFMapCreatedCallback? onMapCreated, Set<Factory<OneSequenceGestureRecognizer>> gestureRecognizers = const <Factory<OneSequenceGestureRecognizer>>{}, String? mapId, String? style, MFMapType mapType = MFMapType.roadmap, MFMinMaxZoom minMaxZoomPreference = MFMinMaxZoom.unbounded, bool rotateGesturesEnabled = true, bool scrollGesturesEnabled = true, bool zoomGesturesEnabled = true, bool tiltGesturesEnabled = true, bool myLocationEnabled = false, bool myLocationButtonEnabled = false, bool poisEnabled = true, bool buildingsEnabled = true, VoidCallback? onCameraMoveStarted, MFCameraPositionCallback? onCameraMove, VoidCallback? onCameraIdle, MFLatLngCallback? onTap, MFMapPOICallback? onPOITap, MFMapBuildingCallback? onBuildingTap, MFMapPlaceCallback? onPlaceTap, MFDataSourceFeatureCallback? onDataSourceFeatureTap, Set<MFMarker> markers = const <MFMarker>{}, Set<MFCircle> circles = const <MFCircle>{}, Set<MFPolygon> polygons = const <MFPolygon>{}, Set<MFPolyline> polylines = const <MFPolyline>{}, Set<MFPOI> pois = const <MFPOI>{}, Set<MFBuilding> buildings = const <MFBuilding>{}, Set<MFTileOverlay> tileOverlays = const <MFTileOverlay>{}, Set<MFImageOverlay> imageOverlays = const <MFImageOverlay>{}, Set<MFDirectionsRenderer> directionsRenderers = const <MFDirectionsRenderer>{}})
const

Properties

buildings → Set<MFBuilding>
Buildings to be placed on the map.
final
buildingsEnabled → bool
Enables or disables showing 3D buildings where available
final
circles → Set<MFCircle>
Circles to be placed on the map.
final
directionsRenderers → Set<MFDirectionsRenderer>
Directions renderers to be placed on the map.
final
gestureRecognizers → Set<Factory<OneSequenceGestureRecognizer>>
Which gestures should be consumed by the map.
final
hashCode → int
The hash code for this object.
no setterinherited
imageOverlays → Set<MFImageOverlay>
Image overlays to be placed on the map.
final
initialCameraPosition → MFCameraPosition?
The initial position of the map's camera.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mapId → String?
An opaque identifier for a custom map configuration.
final
mapType → MFMapType
Type of map tiles to be rendered.
final
markers → Set<MFMarker>
Markers to be placed on the map.
final
minMaxZoomPreference → MFMinMaxZoom
Preferred bounds for the camera zoom level.
final
myLocationButtonEnabled → bool
Enables or disables the my-location button.
final
myLocationEnabled → bool
Enabling this feature requires adding location permissions to both native platforms of your app.
final
onBuildingTap → MFMapBuildingCallback?
Called after a base map building has been tapped
final
onCameraIdle → VoidCallback?
Called when camera movement has ended, there are no pending animations and the user has stopped interacting with the map.
final
onCameraMove → MFCameraPositionCallback?
Called repeatedly as the camera continues to move after an onCameraMoveStarted call.
final
onCameraMoveStarted → VoidCallback?
Called when the camera starts moving.
final
onDataSourceFeatureTap → MFDataSourceFeatureCallback?
Called when user taps on the data source features
final
onMapCreated → MFMapCreatedCallback?
Callback method for when the map is ready to be used. Used to receive a MFMapViewController for this Map4dMap.
final
onPlaceTap → MFMapPlaceCallback?
final
onPOITap → MFMapBuildingCallback?
Called after a base map POI has been tapped
final
onTap → MFLatLngCallback?
Called when did tap at coordinate
final
pois → Set<MFPOI>
POIs to be placed on the map.
final
poisEnabled → bool
Enables or disables showing points of interest
final
polygons → Set<MFPolygon>
Polygons to be placed on the map.
final
polylines → Set<MFPolyline>
Polylines to be placed on the map.
final
rotateGesturesEnabled → bool
True if the map view should respond to rotate gestures.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollGesturesEnabled → bool
True if the map view should respond to scroll gestures.
final
style → String?
The locally configured style for the map.
final
tileOverlays → Set<MFTileOverlay>
Tile overlays to be placed on the map.
final
tiltGesturesEnabled → bool
True if the map view should respond to tilt gestures.
final
zoomGesturesEnabled → bool
True if the map view should respond to zoom gestures.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited