MFMapViewController class

Properties

hashCode → int
The hash code for this object.
no setterinherited
mapId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

animateCamera(MFCameraUpdate cameraUpdate) → Future<void>
cameraForBounds(MFLatLngBounds bounds, {double padding = 0}) → Future<MFCameraPosition>
clearTileCache(MFTileOverlayId tileOverlayId) → Future<void>
Clears the tile cache so that all tiles will be requested again from the TileProvider.
fitBounds(MFLatLngBounds bounds, {double padding = 0}) → Future<void>
getBounds() → Future<MFLatLngBounds?>
Return MFLatLngBounds defining the region that is visible in a map.
getCameraPosition() → Future<MFCameraPosition?>
getLatLng(MFScreenCoordinate screenCoordinate) → Future<MFLatLng>
Returns the LatLng for a screenCoordinate (in pixels) of the viewport.
getLogicalPixelsForMeters(double meters) → Future<double>
getMetersForLogicalPixels(double lp) → Future<double>
getScreenCoordinate(MFLatLng latLng) → Future<MFScreenCoordinate>
Returns the MFScreenCoordinate for a given viewport LatLng.
getZoomLevel() → Future<double>
Returns the current zoom level of the map
moveCamera(MFCameraUpdate cameraUpdate) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSourceOpacity(String source, double opacity) → Future<void>
setTime(DateTime time) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

init(int mapId, _MFMapViewState mapState) → Future<MFMapViewController>
Initialize control of a Map4d with mapId.