MFBitmap class
Defines a bitmap image. For a marker, this class can be used to set the image of the marker icon. For a ground overlay, it can be used to set the image to place on the surface of the earth.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object - Convert the object to a Json format.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromAssetImage(
ImageConfiguration configuration, String assetName, {AssetBundle? bundle, String? package, bool mipmaps = true}) → Future< MFBitmap> - Creates a MFBitmap from an asset image.
-
fromBytes(
Uint8List byteData) → MFBitmap - Creates a BitmapDescriptor using an array of bytes that must be encoded as PNG.
Constants
- defaultIcon → const MFBitmap
- Creates a BitmapDescriptor that refers to the default marker image.