MFImageOverlay class
A set of images which are displayed on top of the base map tiles.
Constructors
- MFImageOverlay({required MFImageOverlayId imageOverlayId, required MFBitmap image, required MFLatLngBounds bounds, double transparency = 0.0, int zIndex = 0, bool visible = true})
-
Creates an immutable representation of a MFImageOverlay to draw on
Map4dMap.const
Properties
- bounds → MFLatLngBounds
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- image → MFBitmap
-
final
- imageOverlayId → MFImageOverlayId
-
Uniquely identifies a MFImageOverlay.
final
- mapsId → MFImageOverlayId
-
A identifier for this object.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transparency → double
-
The transparency of the image overlay. The default transparency is 0 (opaque).
final
- visible → bool
-
The visibility for the image overlay. The default visibility is true.
final
- zIndex → int
-
The image overlay's zIndex, i.e., the order in which it will be drawn where
overlays with larger values are drawn above those with lower values
final
Methods
-
clone(
) → MFImageOverlay - Returns a duplicate of this object.
-
copyWith(
{double? transparencyParam, int? zIndexParam, bool? visibleParam}) → MFImageOverlay - Creates a new MFImageOverlay object whose values are the same as this instance, unless overwritten by the specified parameters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object - Converts this object to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override