zIndex property
The image overlay's zIndex, i.e., the order in which it will be drawn where overlays with larger values are drawn above those with lower values
Implementation
final int zIndex;
The image overlay's zIndex, i.e., the order in which it will be drawn where overlays with larger values are drawn above those with lower values
final int zIndex;