MFPOI class
Draws a POI on the map.
- Annotations
Constructors
- MFPOI({required MFPOIId poiId, bool consumeTapEvents = false, MFLatLng position = const MFLatLng(0.0, 0.0), String title = '', Color titleColor = Colors.blue, MFBitmap icon = MFBitmap.defaultIcon, String type = 'point', bool visible = true, int zIndex = 0, VoidCallback? onTap})
-
Creates an immutable representation of a MFPOI to draw on
Map4dMap.const
Properties
- consumeTapEvents → bool
-
True if the MFPOI consumes tap events.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- icon → MFBitmap
-
A description of the bitmap used to draw the POI icon.
final
- mapsId → MFPOIId
-
A identifier for this object.
no setter
- onTap → VoidCallback?
-
Callbacks to receive tap events for POI placed on this map.
final
- poiId → MFPOIId
-
Uniquely identifies a MFPOI.
final
- position → MFLatLng
-
Geographical location of the POI.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
Title of the POI.
final
- titleColor → Color
-
Title color in ARGB format, the same format used by Color. The default value is transparent (0x00000000).
final
- type → String
-
Subtitle of the POI. - TODO
Type of the POI.
final
- visible → bool
-
True if the POI is visible.
final
- zIndex → int
-
The z-index of the POI, used to determine relative drawing order of
map overlays.
final
Methods
-
clone(
) → MFPOI - Creates a new MFPOI object whose values are the same as this instance.
-
copyWith(
{bool? consumeTapEventsParam, MFLatLng? positionParam, String? titleParam, Color? titleColorParam, String? typeParam, MFBitmap? iconParam, bool? visibleParam, int? zIndexParam, VoidCallback? onTapParam}) → MFPOI - Creates a new MFPOI object whose values are the same as this instance, unless overwritten by the specified parameters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object - Converts this object to something serializable in JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override